eapFromRes.RdCollects EAP results in a wide data frame.
eapFromRes(resultsObj, idVarName = NULL, verbose = TRUE)The object returned by getResults.
Optional: character vector of individual student id. This is only to provide compatibility with older package versions. Specification of this argument is only necessary if the function gives an error.
Print messages to console?
A data frame with several columns, model name, student ID, dimension name, group name, EAP and the corresponding standard error.
### read exemplary results object
file <- system.file("extdata", "results.rda", package = "eatModel")
if (nzchar(file)) {
load(file)
eap <- eapFromRes(res)
}