get.itn.RdReads Conquest files comprising item analyses generated by the itanal statement.
get.itn(file)A data frame with 18 columns:
Number of the item in the analysis
Name of the item
Response category label
Score of this response category
Total number of students who responded to this item
Number of students who gave this response
Number of students who gave this response as a percentage of the total number of respondents to the item
Percentage of students who answered this item correctly
Item discrimination
Point-biserial correlation for this response
T-Value of the significance test whether the point-biserial correlation is different from 0
p-Value of the significance test whether the point-biserial correlation is different from 0
Mean ability (in the first latent dimension) of students who gave this response (based on plausible values)
Standard deviation of ability of students who gave this response (based on plausible values)
Item threshold
Item delta
If the model is multidimensional, the mean and standard deviation of the ability of students who gave the respective response will be shown for each dimension.
See pp. 193 of Wu, M.L., Adams, R.J., Wilson, M.R., & Haldane, S.A. (2007). ACER ConQuest Version 2.0. Generalised Item Response Modeling Software. Camberwell, Victoria: ACER Press.
file <- system.file("extdata", "twodim.itn", package = "eatModel")
if (nzchar(file)) {
itn <- get.itn(file)
}