get.plausible.RdThis function reads Conquest plausible value files and automatically identifies the number of cases, the number of plausible values and the number of dimensions.
get.plausible(file, quiet = FALSE, forConquestResults = FALSE)A data frame with one row per person containing the following columns:
Case number
Identifier for this case
Plausible values columns. Columns are named pv.[number of PV].[number of dimension]. For example, pv.5.2 refers to the 5th plausible value of the second dimension.
Expected a posteriori (EAP) ability estimate for each person. Columns are named eap_Dim.[number of dimension]. For example, eap_Dim.2 refers to the eap estimate of the second dimension.
Standard error of the EAP estimate. Columns are named se.eap_Dim.[number of dimension]. For example, se.eap_Dim.2 refers to the standard error of the EAP estimate of the second dimension.
file <- system.file("extdata", "twodim.pvl", package = "eatModel")
if (nzchar(file)) {
pv <- get.plausible(file)
}
#> 2907 persons and 2 dimensions(s) found.
#> 5 plausible values were drawn for each person on each dimension.