get.wle.RdRead Conquest files comprising maximum likelihood estimates (MLE) or weighted likelihood estimates (WLE).
get.wle(file)A data frame with one row per person containing the following columns:
Case number
Identifier for this case
Number of items this person answered correctly
Number of total items presented to this person
WLE or MLE estimate. The last number of the columns name indicates the dimension the WLE or MLE estimate belongs to.
Standard error of WLE or MLE estimate. The last number of the columns name indicates the dimension the WLE or MLE estimate belongs to.
See pp. 230 of Wu, M.L., Adams, R.J., Wilson, M.R., & Haldane, S.A. (2007). ACER ConQuest Version 2.0. Generalised Item Response Modeling Software. Camberwell, Victoria: ACER Press.
file <- system.file("extdata", "twodim.wle", package = "eatModel")
if (nzchar(file)) {
wle <- get.wle(file)
}
#> Found valid WLEs of 2907 person(s) for 2 dimension(s).