multiEquatErrorreplaceLinkingError.RdmultiEquatError computes linking errors for three
measurement occasions. replaceLinkingError serves to integrate this
linking error into the object created by equat1pl. The linking
error then can be transformed with subsequent function transformToBista.
For an illustration of the workflow, see the examples included in the help page
of multiEquatError.
replaceLinkingError (equatingList, multiEquatError_output, verbose = TRUE, digits = 4)
The object returned by equat1pl, for measurement occasion 1 vs. 3.
The object returned by multiEquatError which contains the linking error
for measurement occasion 1 vs. 3.
Logical: Print information about old (original) and new (replaced) linking error to console?
Number of decimals for printing information about old (original) and new (replaced) linking error
The 'equatingList' object with replaced linking errors. This object can be processed
subsequently by transformToBista
# see the examples in the help page of 'multiEquatError'