runModel.RdStart the estimation of an IRT model defined by defineModel. runModel
should be called with the argument returned by defineModel.
runModel(defineModelObj, show.output.on.console = FALSE,
show.dos.console = TRUE, wait = TRUE, onlySkeleton = FALSE)The object returned by defineModel.
Applies only if defineModel previously was called with software = "conquest".
Logical: Should the output of the conquest console be printed on the R console during estimation?
Applies only if defineModel previously was called with software = "conquest".
Logical: Should the output of the conquest console be printed on screen?
Applies only if defineModel previously was called with software = "conquest".
A logical (not NA) indicating whether the R interpreter should wait for the command to finish,
or run it asynchronously.
Applies only if defineModel previously was called with software = "mirt".
If TRUE, the IRT model is not estimated. Instead, only the model specification is returned
as a data.frame, allowing the user to check whether the model has been specified as desired.
If defineModel previously was called with software = "tam", the returned value
is nearly identically to the corresponding TAM output. Accordingly, if defineModel
previously was called with software = "mirt", the returned value is nearly identically to the
corresponding mirt output. If defineModel previously was called with
software = "conquest", the returned value contains only internally used information useful for
getResults.
# see examples in the help file of defineModel()