Read ConQuest ‘itanal’ Output Files
get.itn.RdReads Conquest files comprising item analyses generated by the itanal statement.
Value
A data frame with 18 columns:
- item.nr
Number of the item in the analysis
- item.name
Name of the item
- Label
Response category label
- Score
Score of this response category
- n.valid
Total number of students who responded to this item
- Abs.Freq
Number of students who gave this response
- Rel.Freq
Number of students who gave this response as a percentage of the total number of respondents to the item
- item.p
Percentage of students who answered this item correctly
- diskrim
Item discrimination
- pt.bis
Point-biserial correlation for this response
- t.value
T-Value of the significance test whether the point-biserial correlation is different from 0
- p.value
p-Value of the significance test whether the point-biserial correlation is different from 0
- PV1.Avg.1
Mean ability (in the first latent dimension) of students who gave this response (based on plausible values)
- PV1.SD.1
Standard deviation of ability of students who gave this response (based on plausible values)
- threshold
Item threshold
- delta
Item delta
If the model is multidimensional, the mean and standard deviation of the ability of students who gave the respective response will be shown for each dimension.
References
See pp. 193 of Wu, M.L., Adams, R.J., Wilson, M.R., & Haldane, S.A. (2007). ACER ConQuest Version 2.0. Generalised Item Response Modeling Software. Camberwell, Victoria: ACER Press.
Examples
file <- system.file("extdata", "twodim.itn", package = "eatModel")
itn <- get.itn(file)