Deviance Plot for mirt objects
plotDevianceMirt.RdPlots the deviance change in every iteration for IRT models estimated with mirt
Arguments
- mirt.obj
The object returned by
mirt- omitUntil
An optional value indicating number of iterations to be omitted for plotting.
- adaptWindow
Logical: Should the size of the output window be adjusted to accommodate the additional information about the R session and available memory? This option should not be used if the plots are not to be displayed directly but written to a PDF file.