multiEquatError computes linking errors for three
measurement occasions. replaceLinkingError serves to integrate this
linking error into the object created by equat1pl. The linking
error then can be transformed with subsequent function transformToBista.
For an illustration of the workflow, see the examples included in the help page
of multiEquatError.
Arguments
- equatingList
The object returned by
equat1pl, for measurement occasion 1 vs. 3.- multiEquatError_output
The object returned by
multiEquatErrorwhich contains the linking error for measurement occasion 1 vs. 3.- verbose
Logical: Print information about old (original) and new (replaced) linking error to console?
- digits
Number of decimals for printing information about old (original) and new (replaced) linking error
Value
The 'equatingList' object with replaced linking errors. This object can be processed
subsequently by transformToBista